@@ -28,11 +28,7 @@ import tempfile
 import time
 import multiprocessing
 
-from paunch import runner as containers_runner
-
 logger = None
-RUNNER = containers_runner.DockerRunner(
-        'docker-puppet')
 
 
 def get_logger():
@@ -63,9 +59,19 @@ def short_hostname():
 
 
 def pull_image(name):
-    log.info('Pulling image: %s' % name)
+
+    subproc = subprocess.Popen(['/usr/bin/docker', 'inspect', name],
+                                stdout=subprocess.PIPE,
+                                stderr=subprocess.PIPE)
+    cmd_stdout, cmd_stderr = subproc.communicate()
+    retval = subproc.returncode
+    if retval == 0:
+        log.info('Image already exists: %s' % name)
+        return
+
     retval = -1
     count = 0
+    log.info('Pulling image: %s' % name)
     while retval != 0:
         count += 1
         subproc = subprocess.Popen(['/usr/bin/docker', 'pull', name],
@@ -90,7 +96,11 @@ def pull_image(name):
 def match_config_volumes(prefix, config):
     # Match the mounted config volumes - we can't just use the
     # key as e.g "novacomute" consumes config-data/nova
-    volumes = config.get('volumes', [])
+    try:
+        volumes = config.get('volumes', [])
+    except AttributeError:
+        log.error('Error fetching volumes. Prefix: %s - Config: %s' % (prefix, config))
+        raise
     return sorted([os.path.dirname(v.split(":")[0]) for v in volumes if
                    v.startswith(prefix)])
 
@@ -190,8 +200,8 @@ for service in (json_data or []):
             configs[config_volume][2] = '%s\n%s' % (configs[config_volume][2],
                                                     manifest)
         if configs[config_volume][3] != config_image:
-            log.warn("Config containers do not match even though"
-                     " shared volumes are the same!")
+            log.warning("Config containers do not match even though"
+                        " shared volumes are the same!")
         if volumes:
             configs[config_volume][4].extend(volumes)
 
@@ -213,7 +223,7 @@ with open(sh_script, 'w') as script_file:
     mkdir -p /etc/puppet
     cp -a /tmp/puppet-etc/* /etc/puppet
     rm -Rf /etc/puppet/ssl # not in use and causes permission errors
-    echo "{\\"step\\": $STEP}" > /etc/puppet/hieradata/docker_puppet.json
+    echo "{\\"step\\": $STEP}" > /etc/puppet/hieradata/docker.json
     TAGS=""
     if [ -n "$PUPPET_TAGS" ]; then
         TAGS="--tags \"$PUPPET_TAGS\""
@@ -227,10 +237,7 @@ with open(sh_script, 'w') as script_file:
     sync
 
     set +e
-    # $::deployment_type in puppet-tripleo
-    export FACTER_deployment_type=containers
-    export FACTER_uuid=$(cat /sys/class/dmi/id/product_uuid | tr '[:upper:]' '[:lower:]')
-    FACTER_hostname=$HOSTNAME /usr/bin/puppet apply --summarize \
+    FACTER_hostname=$HOSTNAME FACTER_uuid=docker /usr/bin/puppet apply --summarize \
     --detailed-exitcodes --color=false --logdest syslog --logdest console --modulepath=/etc/puppet/modules:/usr/share/openstack-puppet/modules $TAGS /etc/config.pp
     rc=$?
     set -e
@@ -247,65 +254,29 @@ with open(sh_script, 'w') as script_file:
                 rsync_srcs+=" $d"
             fi
         done
-        # On stack update, if a password was changed in a config file,
-        # some services (e.g. mysql) must change their internal state
-        # (e.g. password in mysql DB) when paunch restarts them; and
-        # they need the old password to achieve that.
-        # For those services, we update the config hash to notify
-        # paunch that a restart is needed, but we do not update the
-        # password file in docker-puppet if the file already existed
-        # before and let the service regenerate it instead.
-        password_files="/root/.my.cnf"
-
-        exclude_files=""
-        for p in $password_files; do
-            if [ -f "$p" -a -f "/var/lib/config-data/${NAME}$p" ]; then
-                exclude_files+=" --exclude=$p"
-            fi
-        done
-
-        # Exclude read-only mounted directories/files which we do not want
-        # to copy or delete.
-        ro_files="/etc/puppetlabs/ /opt/puppetlabs/"
-        for ro in $ro_files; do
-            if [ -e "$ro" ]; then
-                exclude_files+=" --exclude=$ro"
-            fi
-        done
-
-        rsync -a -R --delay-updates --delete-after $exclude_files $rsync_srcs /var/lib/config-data/${NAME}
+        rsync -a -R --delay-updates --delete-after $rsync_srcs /var/lib/config-data/${NAME}
 
 
         # Also make a copy of files modified during puppet run
         # This is useful for debugging
         echo "Gathering files modified after $(stat -c '%y' $origin_of_time)"
         mkdir -p /var/lib/config-data/puppet-generated/${NAME}
-        rsync -a -R -0 --delay-updates --delete-after $exclude_files \
+        rsync -a -R -0 --delay-updates --delete-after \
                       --files-from=<(find $rsync_srcs -newer $origin_of_time -not -path '/etc/puppet*' -print0) \
                       / /var/lib/config-data/puppet-generated/${NAME}
 
         # Write a checksum of the config-data dir, this is used as a
         # salt to trigger container restart when the config changes
-        # note: while being excluded from the output, password files
-        # are still included in checksum computation
-        additional_checksum_files=""
-        excluded_original_passwords=""
-        for p in $password_files; do
-            if [ -f "$p" ]; then
-                additional_checksum_files+=" $p"
-                excluded_original_passwords+=" --exclude=/var/lib/config-data/*${p}"
-            fi
-        done
         # We need to exclude the swift rings and their backup as those change over time and
         # containers do not need to restart if they change
-        EXCLUDE=--exclude='*/etc/swift/backups/*'\ --exclude='*/etc/swift/*.ring.gz'\ --exclude='*/etc/swift/*.builder'\ --exclude='*/etc/libvirt/passwd.db'\ ${excluded_original_passwords}
+        EXCLUDE=--exclude='*/etc/swift/backups/*'\ --exclude='*/etc/swift/*.ring.gz'\ --exclude='*/etc/swift/*.builder'\ --exclude='*/etc/libvirt/passwd.db'
         # We need to repipe the tar command through 'tar xO' to force text
         # output because otherwise the sed command cannot work. The sed is
         # needed because puppet puts timestamps as comments in cron and
         # parsedfile resources, hence triggering a change at every redeploy
-        tar -c --mtime='1970-01-01' $EXCLUDE -f - /var/lib/config-data/${NAME} $additional_checksum_files | tar xO | \
+        tar -c --mtime='1970-01-01' $EXCLUDE -f - /var/lib/config-data/${NAME} | tar xO | \
                 sed '/^#.*HEADER.*/d' | md5sum | awk '{print $1}' > /var/lib/config-data/${NAME}.md5sum
-        tar -c --mtime='1970-01-01' $EXCLUDE -f - /var/lib/config-data/puppet-generated/${NAME} $additional_checksum_files --mtime='1970-01-01' | tar xO \
+        tar -c --mtime='1970-01-01' $EXCLUDE -f - /var/lib/config-data/puppet-generated/${NAME} --mtime='1970-01-01' | tar xO \
                 | sed '/^#.*HEADER.*/d' | md5sum | awk '{print $1}' > /var/lib/config-data/puppet-generated/${NAME}.md5sum
     fi
     """)
@@ -326,14 +297,12 @@ def mp_puppet_config((config_volume, puppet_tags, manifest, config_image, volume
             man_file.write('include ::tripleo::packages\n')
             man_file.write(manifest)
 
-        uname = RUNNER.unique_container_name('docker-puppet-%s' %
-                                             config_volume)
-        rm_container(uname)
+        rm_container('docker-puppet-%s' % config_volume)
         pull_image(config_image)
 
         dcmd = ['/usr/bin/docker', 'run',
                 '--user', 'root',
-                '--name', uname,
+                '--name', 'docker-puppet-%s' % config_volume,
                 '--env', 'PUPPET_TAGS=%s' % puppet_tags,
                 '--env', 'NAME=%s' % config_volume,
                 '--env', 'HOSTNAME=%s' % short_hostname(),
@@ -342,7 +311,7 @@ def mp_puppet_config((config_volume, puppet_tags, manifest, config_image, volume
                 '--volume', '/etc/localtime:/etc/localtime:ro',
                 '--volume', '%s:/etc/config.pp:ro,z' % tmp_man.name,
                 '--volume', '/etc/puppet/:/tmp/puppet-etc/:ro,z',
-                '--volume', '/usr/share/openstack-puppet/modules/:/usr/share/openstack-puppet/modules/:ro',
+                '--volume', '/usr/share/openstack-puppet/modules/:/usr/share/openstack-puppet/modules/:ro,z',
                 '--volume', '%s:/var/lib/config-data/:z' % os.environ.get('CONFIG_VOLUME_PREFIX', '/var/lib/config-data'),
                 '--volume', 'tripleo_logs:/var/log/tripleo/',
                 # Syslog socket for puppet logs
@@ -352,9 +321,6 @@ def mp_puppet_config((config_volume, puppet_tags, manifest, config_image, volume
                 '--volume', '/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro',
                 '--volume', '/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro',
                 '--volume', '/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro',
-                # facter caching
-                '--volume', '/var/lib/container-puppet/puppetlabs/facter.conf:/etc/puppetlabs/facter/facter.conf:ro',
-                '--volume', '/var/lib/container-puppet/puppetlabs/:/opt/puppetlabs/:ro',
                 # script injection
                 '--volume', '%s:%s:z' % (sh_script, sh_script) ]
 
@@ -394,7 +360,7 @@ def mp_puppet_config((config_volume, puppet_tags, manifest, config_image, volume
             if cmd_stderr:
                 log.debug(cmd_stderr)
             # only delete successful runs, for debugging
-            rm_container(uname)
+            rm_container('docker-puppet-%s' % config_volume)
 
         log.info('Finished processing puppet configs for %s' % (config_volume))
         return subproc.returncode
